@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for B-Prolog 8.1 and later versions
-%  Last updated on August 16, 2024
+%  Last updated on September 9, 2024
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  SPDX-FileCopyrightText: 1998-2024 Paulo Moura <pmoura@logtalk.org>
@@ -192,8 +192,8 @@ findall(Term, Goal, List, Tail) :-
 
 % '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
 %
-% valid candidates are proprietary built-in predicates with
-% no side-effects when called with ground arguments
+% valid candidates are proprietary built-in predicates with no
+% side-effects when called with ground arguments
 
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(name(_, _)).
 
