@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for XVM 10.0.0 and later versions
-%  Last updated on June 26, 2024
+%  Last updated on September 9, 2024
 %
 %  This file is part of Logtalk <https://logtalk.org/>
 %  SPDX-FileCopyrightText: 1998-2024 Paulo Moura <pmoura@logtalk.org>
@@ -156,12 +156,13 @@
 
 % '$lgt_candidate_tautology_or_falsehood_goal_hook'(@callable)
 %
-% valid candidates are proprietary built-in predicates with
-% no side-effects when called with ground arguments
+% valid candidates are proprietary built-in predicates with no
+% side-effects when called with ground arguments
 
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(?=(_, _)).
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(atom_number(_, _)).
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(attvar(_)).
+'$lgt_candidate_tautology_or_falsehood_goal_hook'(cyclic_term(_)).
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(dif(_, _)).
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(is_list(_)).
 '$lgt_candidate_tautology_or_falsehood_goal_hook'(is_list_or_partial_list(_)).
@@ -780,14 +781,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
-% term_hash(@callable, +integer, +integer, -integer)
-
-:- if(\+ predicate_property(term_hash(_,_,_,_), built_in)).
-
-	term_hash(_, _, _, _) :-
-		fail.
-
-:- endif.
+% term_hash(@callable, +integer, +integer, -integer) -- built-in
 
 
 
