@@ -3,10 +3,10 @@
 #############################################################################
 ## 
 ##   Logtalk installation script
-##   Last updated on December 17, 2023
+##   Last updated on June 28, 2024
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
-##   SPDX-FileCopyrightText: 1998-2023 Paulo Moura <pmoura@logtalk.org>
+##   SPDX-FileCopyrightText: 1998-2024 Paulo Moura <pmoura@logtalk.org>
 ##   SPDX-License-Identifier: Apache-2.0
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
@@ -151,7 +151,7 @@ ln -sf ../share/logtalk/integration/cxlgt.sh cxlgt
 ln -sf ../share/logtalk/integration/eclipselgt.sh eclipselgt
 ln -sf ../share/logtalk/integration/gplgt.sh gplgt
 ln -sf ../share/logtalk/integration/jiplgt.sh jiplgt
-ln -sf ../share/logtalk/integration/lvmlgt.sh lvmlgt
+ln -sf ../share/logtalk/integration/xvmlgt.sh xvmlgt
 ln -sf ../share/logtalk/integration/quintuslgt.sh quintuslgt
 ln -sf ../share/logtalk/integration/sicstuslgt.sh sicstuslgt
 ln -sf ../share/logtalk/integration/swilgt.sh swilgt
@@ -171,17 +171,25 @@ if [ "$(command -v install-info)" != "" ]; then
 	mkdir -p ../../info
 	cd ../../info || exit 1
 	if [ -f ../logtalk/docs/LogtalkAPIs-$version_base.info ] ; then
-		cp ../logtalk/docs/LogtalkAPIs-$version_base.info .
 		if [ -f dir ] ; then
-			install-info --silent --delete LogtalkAPIs-*.info
+			for file in ./LogtalkAPIs-*.info ; do
+				[ -e "$file" ] || continue
+				rm "$file"
+				install-info --silent --delete "$file" dir > /dev/null 2>&1
+			done
 		fi
+		cp ../logtalk/docs/LogtalkAPIs-$version_base.info .
 		install-info LogtalkAPIs-$version_base.info dir
 	fi
 	if [ -f ../logtalk/manuals/TheLogtalkHandbook-$version_base.info ] ; then
-		cp ../logtalk/manuals/TheLogtalkHandbook-$version_base.info .
 		if [ -f dir ] ; then
-			install-info --silent --delete TheLogtalkHandbook-*.info
+			for file in ./TheLogtalkHandbook-*.info ; do
+				[ -e "$file" ] || continue
+				rm "$file"
+				install-info --silent --delete "$file" dir > /dev/null 2>&1
+			done
 		fi
+		cp ../logtalk/manuals/TheLogtalkHandbook-$version_base.info .
 		install-info TheLogtalkHandbook-$version_base.info dir
 	fi
 	echo "Ensure that the \"$prefix/share/info\" directory is in your INFOPATH."
@@ -197,13 +205,13 @@ echo "* CxProlog (0.98.1 or later):        cxlgt"
 echo "* ECLiPSe (6.1#143 or later):        eclipselgt"
 echo "* GNU Prolog (1.4.5 or later):       gplgt"
 echo "* JIProlog (4.1.7.1 or later):       jiplgt      (first run may require sudo)"
-echo "* LVM (6.3.0 or later):              lvmlgt"
 echo "* Quintus Prolog (3.3 or later):     quintuslgt  (experimental)"
 echo "* SICStus Prolog (4.1.0 or later):   sicstuslgt"
 echo "* SWI-Prolog (6.6.0 or later):       swilgt"
 echo "* Tau Prolog (0.3.2 or later):       taulgt"
 echo "* Trealla Prolog (2.18.7 or later):  tplgt"
 echo "* XSB (3.8.0 or later):              xsblgt      (first run may require sudo)"
+echo "* XVM (10.0.0 or later):             xvmlgt"
 echo "* YAP (6.3.4 or later):              yaplgt"
 echo
 echo "Links to the Prolog integration scripts can be found on \"$prefix/bin\"."
@@ -212,8 +220,9 @@ echo "on your execution path."
 echo
 echo "Users should ensure that the environment variable LOGTALKHOME is set to"
 echo "\"$prefix/share/logtalk\" and then run the \"logtalk_user_setup\" shell script"
-echo "once before running the integration scripts. For more details on manual"
-echo "installation setup, see the \"INSTALL.md\" file."
+echo "once before running the integration scripts to ensure their LOGTALKUSER"
+echo "directory is up-to-date. For more details on manual installation setups,"
+echo "see the \"INSTALL.md\" file."
 echo
 echo "If you get an unexpected failure when using one of the Prolog integration"
 echo "scripts, consult the \"$prefix/share/logtalk/adapters/NOTES.md\" file"
